==> tecfy_corev2_package-1.1.78.tar.gz: lib/views/components/entity/date.property.dart <==
part of tecfy_corev2_client_package;

class DateProperty extends StatefulWidget {
  final String? label;
  final String? description;
  final bool isRequired;
  final dynamic initalValue;
  final void Function(DateTime?)? onChanged;
  DateProperty({
    this.label,
    this.description,
    this.isRequired = false,
    this.initalValue,
    this.onChanged,
  });
  @override
  _DatePropertyState createState() => _DatePropertyState();
}

class _DatePropertyState extends State<DateProperty> {
  DateTime? _selectedValue;

  @override
  void initState() {
    if (widget.initalValue != null) {
      if (widget.initalValue is String) {
        _selectedValue = BaseModel.parseUTC(widget.initalValue);
      } else if (widget.initalValue is DateTime) {
        _selectedValue = widget.initalValue;
      }
    }
    super.initState();
  }

  void _onPressed() async {
    var value = await showDatePicker(
        builder: (context, child) {
          return Theme(
            data: Theme.of(context).copyWith(
              colorScheme: ColorScheme.light(
                primary: ThemeService.mainColor,
                onPrimary: Colors.white,
                onSurface: Colors.black,
              ),
              textButtonTheme: TextButtonThemeData(
                style: TextButton.styleFrom(
                  primary: Colors.black,
                ),
              ),
            ),
            child: child ?? Container(),
          );
        },
        context: context,
        firstDate: DateTime(1900),
        initialDate: _selectedValue ?? DateTime.now().toUtc(),
        lastDate: DateTime(2500));
    setState(() {
      _selectedValue = value?.toUtc();
    });
    widget.onChanged?.call(_selectedValue);
  }

  _onPrint() {
    if (_selectedValue == null && widget.initalValue != null) {
      if (widget.initalValue is String) {
        print('trying to parse');
        _selectedValue = BaseModel.parseUTC(widget.initalValue);
      } else if (widget.initalValue is DateTime) {
        _selectedValue = widget.initalValue;
      }
    }
  }

  @override
  Widget build(BuildContext context) {
    _onPrint();
    return MaterialButton(
      padding: EdgeInsets.all(0),
      onPressed: _onPressed,
      child: widget.label == null
          ? Tooltip(
              message: widget.description ?? '',
              child: TecfyText(_selectedValue != null
                  ? intl.DateFormat("dd/MM/yyyy")
                      .format(_selectedValue!.toLocal())
                  : '[Click To Select]'))
          : Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: <Widget>[
                SizedBox(height: 10),
                Row(
                  children: [
                    Tooltip(
                        message: widget.description ?? '',
                        child: TecfyText(
                          widget.label ?? '',
                          style: ThemeService.labelStyle,
                        )),
                    TecfyText(
                      widget.isRequired ? '*' : '',
                      style:
                          ThemeService.labelStyle.copyWith(color: Colors.red),
                    ),
                  ],
                ),
                TecfyText(_selectedValue != null
                    ? intl.DateFormat("dd/MM/yyyy")
                        .format(_selectedValue!.toLocal())
                    : '[Click To Select]'),
                SizedBox(height: 10),
                Container(height: 1, color: ThemeService.textSubColor)
              ],
            ),
    );
  }
}

==> tecfy_corev2_package-1.1.108.tar.gz: lib/views/components/entity/date.property.dart <==
part of tecfy_corev2_client_package;

class DateProperty extends StatefulWidget {
  final String? label;
  final String? description;
  final bool isRequired;
  final dynamic initalValue;
  final void Function(DateTime?)? onChanged;
  DateProperty({
    this.label,
    this.description,
    this.isRequired = false,
    this.initalValue,
    this.onChanged,
  });
  @override
  _DatePropertyState createState() => _DatePropertyState();
}

class _DatePropertyState extends State<DateProperty> {
  DateTime? _selectedValue;

  @override
  void initState() {
    if (widget.initalValue != null) {
      if (widget.initalValue is String) {
        _selectedValue = BaseModel.parseUTC(widget.initalValue);
      } else if (widget.initalValue is DateTime) {
        _selectedValue = widget.initalValue;
      }
    }
    super.initState();
  }

  void _onPressed() async {
    var value = await showDatePicker(
        builder: (context, child) {
          return Theme(
            data: Theme.of(context).copyWith(
              colorScheme: ColorScheme.light(
                primary: ThemeService.mainColor,
                onPrimary: Colors.white,
                onSurface: Colors.black,
              ),
              textButtonTheme: TextButtonThemeData(
                style: TextButton.styleFrom(
                  foregroundColor: Colors.black,
                ),
              ),
            ),
            child: child ?? Container(),
          );
        },
        context: context,
        firstDate: DateTime(1900),
        initialDate: _selectedValue ?? DateTime.now().toUtc(),
        lastDate: DateTime(2500));
    setState(() {
      _selectedValue = value?.toUtc();
    });
    widget.onChanged?.call(_selectedValue);
  }

  _onPrint() {
    if (_selectedValue == null && widget.initalValue != null) {
      if (widget.initalValue is String) {
        print('trying to parse');
        _selectedValue = BaseModel.parseUTC(widget.initalValue);
      } else if (widget.initalValue is DateTime) {
        _selectedValue = widget.initalValue;
      }
    }
  }

  @override
  Widget build(BuildContext context) {
    _onPrint();
    return MaterialButton(
      padding: EdgeInsets.all(0),
      onPressed: _onPressed,
      child: widget.label == null
          ? Tooltip(
              message: widget.description ?? '',
              child: TecfyText(_selectedValue != null
                  ? intl.DateFormat("dd/MM/yyyy")
                      .format(_selectedValue!.toLocal())
                  : '[Click To Select]'))
          : Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: <Widget>[
                SizedBox(height: 10),
                Row(
                  children: [
                    Tooltip(
                        message: widget.description ?? '',
                        child: TecfyText(
                          widget.label ?? '',
                          style: ThemeService.labelStyle,
                        )),
                    TecfyText(
                      widget.isRequired ? '*' : '',
                      style:
                          ThemeService.labelStyle.copyWith(color: Colors.red),
                    ),
                  ],
                ),
                TecfyText(_selectedValue != null
                    ? intl.DateFormat("dd/MM/yyyy")
                        .format(_selectedValue!.toLocal())
                    : '[Click To Select]'),
                SizedBox(height: 10),
                Container(height: 1, color: ThemeService.textSubColor)
              ],
            ),
    );
  }
}
